@@ -16,6 +16,7 @@ from datetime import datetime
 from typing import Dict, List
 
 from .literals import (
+    AccessTypeType,
     ChannelStateType,
     ModeType,
     OriginManifestTypeType,
@@ -74,6 +75,7 @@ __all__ = (
     "ResponseOutputItemTypeDef",
     "ScheduleConfigurationTypeDef",
     "ScheduleEntryTypeDef",
+    "SecretsManagerAccessTokenConfigurationTypeDef",
     "SlateSourceTypeDef",
     "SourceLocationTypeDef",
     "SpliceInsertMessageTypeDef",
@@ -87,7 +89,8 @@ __all__ = (
 AccessConfigurationTypeDef = TypedDict(
     "AccessConfigurationTypeDef",
     {
-        "AccessType": Literal["S3_SIGV4"],
+        "AccessType": AccessTypeType,
+        "SecretsManagerAccessTokenConfiguration": "SecretsManagerAccessTokenConfigurationTypeDef",
     },
     total=False,
 )
@@ -590,6 +593,16 @@ class ScheduleEntryTypeDef(_RequiredScheduleEntryTypeDef, _OptionalScheduleEntry
     pass
 
 
+SecretsManagerAccessTokenConfigurationTypeDef = TypedDict(
+    "SecretsManagerAccessTokenConfigurationTypeDef",
+    {
+        "HeaderName": str,
+        "SecretArn": str,
+        "SecretStringKey": str,
+    },
+    total=False,
+)
+
 SlateSourceTypeDef = TypedDict(
     "SlateSourceTypeDef",
     {
